@@ -1,18 +1,17 @@
 package Neo4j::Bolt::NeoValue;
-#use lib '../lib';
-#use lib '../../lib';
+use Neo4j::Client;
+
 BEGIN {
-  our $VERSION = "0.12";
+  our $VERSION = "0.20";
   require Neo4j::Bolt::TypeHandlersC;
-  eval 'require Neo4j::Bolt::Config; 1';
 }
 
-use Inline C => Config =>
-  LIBS => $Neo4j::Bolt::Config::extl,
-  INC => $Neo4j::Bolt::Config::extc,
+use Inline P => Config =>
+  LIBS => $Neo4j::Client::LIBS,
+  INC => $Neo4j::Client::CCFLAGS,
   version => $VERSION,
   name => __PACKAGE__;
-use Inline C => <<'END_NEOVALUE_C';
+use Inline P => <<'END_NEOVALUE_C';
 
 #include <neo4j-client.h>
 #define C_PTR_OF(perl_obj,c_type) ((c_type *)SvIV(SvRV(perl_obj)))
